%define debug_package %{nil}

%define rel                     3

%if 0%{?amzn}
%global	UseVE 1
%define	__python                %(echo which python3 | scl enable rh-python38 -)
%endif

%if 0%{?UseVE}
%define VirtualEnvironment      %{name}-%{version}-%{rel}
%define VirtualEnvironmentPath  %{_prefix}/local/lib/PythonVirtualEnvironments
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^libz-.*\.so|^liblzma-.*\.so|^libjpeg-.*\.so.62.3.0|^llibz-.*\.so|^libpng16-.*\.so
%endif

%if 0%{?centos}0%{?amzn} == 70
%define python3_pkgversion 36
%endif

Summary:	Library for carving binary files

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		hachoir
Version:	3.1.2
Release:	%{rel}%{?dist}
URL:		https://bitbucket.org/haypo/hachoir/wiki/Home

License:	GPL

Group:		Applications/Forensics Tools

Source:		%{name}-%{version}.tar.gz
BuildRoot:	%{_tmppath}/rpm-root-%{name}-%{version}
%if 0%{?fedora} >= 26 || 0%{?centos} == 7
Requires:	python%{python3_pkgversion}-wxpython4
%endif
Obsoletes:      hachoir-core < %{version}
Obsoletes:	hachoir-metadata < %{version}
Obsoletes:	hachoir-parser < %{version}
Obsoletes:	hachoir-regex < %{version}
Obsoletes:	hachoir-subfile < %{version}
Obsoletes:	hachoir-wx < %{version}
Obsoletes:	hachoir-urwid < %{version}
BuildRequires:  gcc-c++

%if 0%{?UseVE}

%if 0%{?amzn}
BuildRequires:  gtk3-devel
BuildRequires:  rh-python36-python-virtualenv rh-python36-python-devel
BuildRequires:  rh-python38-python rh-python38-python-devel
Requires:       rh-python38-python
%endif

%if 0%{?centos} == 8 || 0%{?rhel} == 8
BuildRequires:  python3-virtualenv python38-devel python38
%endif

%if 0%{?centos} == 7 && 0%{?amzn} == 0
BuildRequires:  python36-virtualenv
BuildRequires:  rh-python38-python rh-python38-python-devel
Requires:       rh-python38-python
%endif

%if 0%{?fedora}
BuildRequires:  python3-virtualenv python3-devel
%endif

%else

Requires:	python%{python3_pkgversion}-urwid
BuildRequires:	python%{python3_pkgversion}-devel

%endif

%description
Hachoir is a Python library used to represent of a binary file as a tree of
Python objects. Each object has a type, a value, an address, etc. The goal is
to be able to know the meaning of each bit in a file.

Why using slow Python code instead of fast hardcoded C code? Hachoir has many
interesting features:

 * Autofix: Hachoir is able to open invalid / truncated files
 * Lazy: Open a file is very fast since no information is read from file,
   data are read and/or computed when the user ask for it
 * Types: Hachoir has many predefined field types (integer, bit, string, etc.)
   and supports string with charset (ISO-8859-1, UTF-8, UTF-16, ...)
 * Addresses and sizes are stored in bit, so flags are stored as classic fields
 * Endian: You have to set endian once, and then number are converted in the
   right endian
 * Editor: Using Hachoir representation of data, you can edit, insert, remove
   data and then save in a new file.

%prep
%if 0%{?UseVE}

%setup
sudo mkdir -p %{VirtualEnvironmentPath}
sudo chown %(id -u).%(id -g) %{VirtualEnvironmentPath}
cd %{VirtualEnvironmentPath}
rm -rf %{VirtualEnvironment}

%if 0%{?amzn}
echo virtualenv -p $(echo which python3.8 | scl enable rh-python38 -) %{VirtualEnvironment} | scl enable rh-python36 -
%endif

%if 0%{?centos}0%{?amzn} == 70
echo virtualenv-3 -p $(echo which python3 | scl enable rh-python38 -) %{VirtualEnvironment} | scl enable rh-python38 -
%endif

%if 0%{?centos} == 8
virtualenv-3 -p $(which python3.8) %{VirtualEnvironment}
%endif

%if 0%{?fedora}
virtualenv %{VirtualEnvironment}
%endif

cd %{VirtualEnvironment}
tar zxf %{SOURCE0}

%else

%setup -n %{name}-%{version}

%endif

%build
%if 0%{?UseVE}

cd %{VirtualEnvironmentPath}/%{VirtualEnvironment}
for p in pip urwid 'numpy<1.17' wxPython
do
        sh -c "source bin/activate; pip3 install --upgrade \"$p\""
done
sh -c "source bin/activate; cd %{name}-%{version}; python3 setup.py build"

%else

%py3_build

%endif

%install
%if 0%{?UseVE}

cd %{VirtualEnvironmentPath}/%{VirtualEnvironment}
sh -c "source bin/activate; cd %{name}-%{version}; python3 setup.py install"
%{__mkdir_p} %{buildroot}/%{VirtualEnvironmentPath}
cd %{VirtualEnvironmentPath}
rm -rf %{VirtualEnvironment}/%{name}-%{version}
find %{VirtualEnvironment} | cpio -pdm %{buildroot}/%{VirtualEnvironmentPath}

cd %{buildroot}/%{VirtualEnvironmentPath}/%{VirtualEnvironment}/bin
mkdir -p %{buildroot}/%{_bindir}
cat > %{buildroot}/%{_bindir}/%{name}-grep << 'EOF'
#!/bin/sh

N=$(basename $0)
MA=%{VirtualEnvironment}
VE=%{VirtualEnvironmentPath}

if [ -d $VE ]; then
        source $VE/$MA/bin/activate
        exec python3 $VE/$MA/%{name}-%{version}/$N "$@"
else
        echo $0 cannot be found
        exit 1
fi
EOF

for t in %{name}-*
do
         [[ ! -e %{buildroot}%{_bindir}/$t ]] && ln %{buildroot}%{_bindir}/%{name}-grep %{buildroot}%{_bindir}/$t
done

%else 

%{__rm} -rf %{buildroot}
%py3_install
%if 0%{?centos} == 8
rm %{buildroot}%{_bindir}/hachoir-wx
%endif

%endif

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(644, root, root, 0755)
%doc COPYING README.rst
%attr(0755, root, root)	%{_bindir}/*

%if 0%{?UseVE}

%{VirtualEnvironmentPath}/%{VirtualEnvironment}

%else

%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}-py3*.egg-info

%endif

%changelog
* Wed Jan 26 2022 Lawrence R. Rogers <lrr@cert.org> 3.1.2-3
* Release 3.1.2-3
	Combined VE and non-VE into one spec file.

* Sun May  3 2020 Lawrence R. Rogers <lrr@cert.org> 3.1.2-1
* Release 3.1.2-1
	Hachoir Python 3 version

